Radiative Monte Carlo — TARDIS v0.9.dev692

# Radiative Monte Carlo

The radiative monte carlo is initiated once the model is constructed.

Different line interactions

line_interaction_id == 0: scatter line_interaction_id == 1: downbranch line_interaction_id == 2: macro

## Radiationfield estimators

During the monte-carlo run we collect two estimators for the radiation field:

\[\begin{split}J_\textrm{estimator} &= \sum{\epsilon l}\\ \bar{\nu}_\textrm{estimator} &= \sum{\epsilon \nu l},\end{split}\]

where \(\epsilon, \nu\) are comoving energy and comoving frequency of a packet respectively.

To calculate the temperature and dilution factor we first calculate the mean intensity in each cell ( \(J = \frac{1}{4\pi\, \Delta t\, V} J_\textrm{estimator}\) )., [2].

The weighted mean frequency is used to obtain the radiation temperature. Specifically, the radiation temperature is chosen as the temperature of a black body that has the same weighted mean frequency as has been computed in the simulation. Accordingly,

\[\frac{h \bar{\nu}}{k_{B} T_{R}} = \frac{h}{k_{B} T_{R}} \frac{\bar{\nu}_\textrm{estimator}}{J_\textrm{estimator}} = 24 \zeta(5) \frac{15}{\pi^4},\]

where the evaluation comes from the mean value of

\[\bar{x} = \frac{ \int_0^{\infty} x^4 / (\exp{x} - 1)dx}{\int_0^{\infty} x^3 / (\exp{x} - 1)dx} = 24 \zeta(5) \frac{15}{\pi^4} = 3.8322\dots\]

and so

\[\begin{split}T_{R} &= \frac{1}{\bar{x}} \frac{h}{k_{B}} \frac{\bar{\nu}_\textrm{estimator}}{J_\textrm{estimator}} \\ &= 0.260945 \frac{h}{k_{B}} \frac{\bar{\nu}_\textrm{estimator}}{J_\textrm{estimator}}.\end{split}\]

With the radiation temperature known, we can then obtain our estimate for for the dilution factor. Our radiation field model in the nebular approximation is

\[J = W B(T_{R}) = W \frac{\sigma_{SB}}{\pi} T_{R}^4,\]

i.e. a dilute blackbody. Therefore we use our value of the mean intensity derrived from the estimator (above) to obtain the dilution factor

\[W = \frac{\pi J}{\sigma_{SB} T_{R}^4} = \frac{1}{4\sigma_{SB} T_{R}^4\, \Delta t\, V} J_\textrm{estimator}.\]

There endeth the lesson.